function [data,frange,pic,rx,ry,rz,sx,sy,sz,sd,sp,vp,geoazi]=bsegin(fp1,npts,jtrace)
//   |------------------------------------------------------------|
//   | $Id: bsegin.sci,v 1.4 2009-05-08 22:03:47 pm Exp $         |
//   | Basic Seismic Utilities (BSU)                              |
//   | LANGUAGE: Scilab                                           |
//   | AUTHOR: P. MICHAELS                                        |
//   | FUNCTION NAME: bsegin.sci                                  |
//   | DIRECTORY: BSUROOT/C/bsegy                                 |
//   |  revised for scilab 4.0                                    |
//   |------------------------------------------------------------|
//   | purpose: read a BSEGY file, data and header information    |
//   |          (direct access of trace=jtrace)                   |
//   |          assumes that the file has been opened for binary  |
//   |          read already. fp1=mopen(filen,'rb');              |
//   |------------------------------------------------------------|
//   | Scilab is an interpreter useful for scientifc calculations.|
//   | It is similar to MATLAB and may be obtained free from      |
//   | http://www-rocq.inria.fr/scilab                            |
//   | Scilab is available for many platforms, including LINUX    |
//   |------------------------------------------------------------|
//   |  NOTICE:                                                   |
//   |  Copyright (c) 2009 Paul Michaels                          |
//   |  <pm@cgiss.boisestate.edu>                                 |
//   |  This program is free software; you can                    |
//   |  redistribute it and/or modify it under the terms          |
//   |  of the GNU General Public License as published            |
//   |  by the Free Software Foundation; either version           |
//   |  3 of the License, or (at your option) any later           |
//   |  version.  This program is distributed in the              |
//   |  hope that it will be useful, but                          |
//   |  WITHOUT ANY WARRANTY; without even the implied            |
//   |  warranty of MERCHANTABILITY or FITNESS FOR A              |
//   |  PARTICULAR PURPOSE.  See the GNU General Public           |
//   |  License for more details.                                 |
//   |  You should have received a copy of the GNU                |
//   |  General Public License along with this program;           |
//   |  if not, write to the Free Software Foundation,            |
//   |  Inc., 675 Mass Ave, Cambridge, MA 02139, USA.             |
//   |------------------------------------------------------------|
// NOTE: 32bit vs 64 bit arch:  4 byte integer type ='i' for both
//       type = 'l' is 8 byte integer on 64bit, 4 byte integer on 32bit
// skip to trace jtrace
jbyte=(240+npts*4)*(jtrace-1);  //assumes 4 byte floating point data
mseek(jbyte,fp1,'set');
//header=mget(240,'uc',fp1);   //unsigned character uc
mseek(40,fp1,'cur');

rz=mget(1,'i',fp1);
sz=mget(1,'i',fp1);
sd=mget(1,'i',fp1);
mseek(16,fp1,'cur');
smul1=mget(1,'s',fp1);
smul2=mget(1,'s',fp1);
sx=mget(1,'i',fp1);  //bytes 73-76
sy=mget(1,'i',fp1);  //bytes 77-80
rx=mget(1,'i',fp1); //bytes 81-84
ry=mget(1,'i',fp1); //bytes 85-88
mseek(26,fp1,'cur'); // to byte 114
sampno1=mget(1,'s',fp1); //bytes 115-116 npts
sampint1=mget(1,'s',fp1); //bytes 117-118 sample int in microsec
mseek(62,fp1,'cur');
mst=mget(1,'i',fp1); //byte 181-184 first break pic
mseek(20,fp1,'cur');
geoazi=mget(1,'s',fp1);
mseek(14,fp1,'cur');
spc=mgetstr(4,fp1);     //shot point name 4 char
vpc=mgetstr(4,fp1);     //receiver name 4 char
mseek(12,fp1,'cur');    //takes us to byte 240

//...apply scale factors
if smul1 < 0
  sz=sz/abs(smul1);
  sd=sd/abs(smul1);
  rz=rz/abs(smul1);
else
  sz=sz*abs(smul1);
  sd=sd*abs(smul1);
  rz=rz*abs(smul1);
end
if smul2 < 0
  sx=sx/abs(smul2);
  sy=sy/abs(smul2);
  rx=rx/abs(smul2);
  ry=ry/abs(smul2);
else
  sx=sx*abs(smul2);
  sy=sy*abs(smul2);
  rx=rx*abs(smul2);
  ry=ry*abs(smul2);
end
pic=mst/(1.E+06);
frange=sqrt((rx-sx)^2+(ry-sy)^2+(rz-sz)^2);
//read a trace
data=mget(npts,'f',fp1);  //floating point
sp=sscanf(spc,'%i');
vp=sscanf(vpc,'%i');
