//   |------------------------------------------------------------|
//   | Basic Seismic Utilities (BSU)                              |
//   | LANGUAGE: Scilab                                           |
//   | AUTHOR: P. MICHAELS                      DATE: 16 Apr 2002 |
//   | FUNCTION NAME: delaytmplotR.sci                            |
//   | DIRECTORY: BSUROOT/Scilab                                  |
//   |------------------------------------------------------------|
//   | purpose: plot solution from delaytmR.sci                   |
//   |   (reciprocal refraction shooting across a river, shot     |
//   |    moves, phones stationary on banks)                      |
//   |------------------------------------------------------------|
//   | Scilab is an interpreter useful for scientifc calculations.|
//   | It is similar to MATLAB and may be obtained free from      |
//   | http://www-rocq.inria.fr/scilab                            |
//   | Scilab is available for many platforms, including LINUX    |
//   |------------------------------------------------------------|
//   |  NOTICE:                                                   |
//   |  Copyright (c) 2002 Paul Michaels                          |
//   |  <pm@cgiss.boisestate.edu>                                 |
//   |  This program is free software; you can                    |
//   |  redistribute it and/or modify it under the terms          |
//   |  of the GNU General Public License as published            |
//   |  by the Free Software Foundation; either version           |
//   |  3 of the License, or (at your option) any later           |
//   |  version.  This program is distributed in the              |
//   |  hope that it will be useful, but                          |
//   |  WITHOUT ANY WARRANTY; without even the implied            |
//   |  warranty of MERCHANTABILITY or FITNESS FOR A              |
//   |  PARTICULAR PURPOSE.  See the GNU General Public           |
//   |  License for more details.                                 |
//   |  You should have received a copy of the GNU                |
//   |  General Public License along with this program;           |
//   |  if not, write to the Free Software Foundation,            |
//   |  Inc., 675 Mass Ave, Cambridge, MA 02139, USA.             |
//   |------------------------------------------------------------|
//  Final Plot of delay time solution (structure)
//  Modified to go with delaytmR.sci  (River, Reciprocal Shooting
//                                    with water bottom column added

clear

getf("sclplot.sci");

//---load results from delaytm.sci run
fp1=file('open','struct.dat','old');
struct=read(fp1,-1,4);    // jstation, wx, elev, elev rivrbot
jstation=struct(:,1);
wx=struct(:,2);
elev=struct(:,3);
ewds=struct(:,4);  //new column
file('close',fp1);

save0=zeros(8,1);
hold=0;
//plot2d(jstation,wx,2,"000");    //  wx (refractor)
  save1=sclplot(jstation,wx,...
                " ","Station","Elevation (m)",hold,save0,2);
plot2d(jstation,elev,2,"000");     // shot elev
plot2d(jstation,ewds,2,"000");     //river bottom


//-------------travel time fit plot
x_message('Continue?');

//---load fit from delaytm.sci run
fp1=file('open','ttimes.dat','old');
nshot=read(fp1,1,1);
Nrec=read(fp1,1,1);
times=read(fp1,-1,3);    // flag, observed, calculated 
flag=times(:,1);
d=times(:,2);
dcal=times(:,3);
file('close',fp1);
xdel();
save0=zeros(8,1);
hold=0;
for k=1:nshot
kstart=(k-1)*Nrec+1;
kend=kstart+Nrec-1;
if k==1 then
//  plot2d(flag(kstart:kend),d(kstart:kend),-3);
  save1=sclplot(flag(kstart:kend),d(kstart:kend)*1000,...
                " ","Station","Picks (ms)",hold,save0,-3);
else;
  plot2d(flag(kstart:kend),d(kstart:kend)*1000,-3,"000");
end;  //endif 
  plot2d(flag(kstart:kend),dcal(kstart:kend)*1000,2,"000");
end;  //next k

