//   |------------------------------------------------------------|
//   | $Id: direct.sci,v 1.6 2009-05-08 22:03:48 pm Exp $         |
//   | Basic Seismic Utilities (BSU)                              |
//   | LANGUAGE: Scilab                                           |
//   | AUTHOR: P. MICHAELS                                        |
//   | FUNCTION NAME: delaytm.sci                                 |
//   | DIRECTORY: BSUROOT/Scilab                                  |
//   |  revised for scilab 4.0                                    |
//   |------------------------------------------------------------|
//   | purpose: to compute direct arrival, V1 solution from bref  |
//   |   (normal refraction shooting, common shot gathers)        |
//   |------------------------------------------------------------|
//   | Scilab is an interpreter useful for scientifc calculations.|
//   | It is similar to MATLAB and may be obtained free from      |
//   | http://www-rocq.inria.fr/scilab                            |
//   | Scilab is available for many platforms, including LINUX    |
//   |------------------------------------------------------------|
//   |  NOTICE:                                                   |
//   |  Copyright (c) 2009 Paul Michaels                          |
//   |  <pm@cgiss.boisestate.edu>                                 |
//   |  This program is free software; you can                    |
//   |  redistribute it and/or modify it under the terms          |
//   |  of the GNU General Public License as published            |
//   |  by the Free Software Foundation; either version           |
//   |  3 of the License, or (at your option) any later           |
//   |  version.  This program is distributed in the              |
//   |  hope that it will be useful, but                          |
//   |  WITHOUT ANY WARRANTY; without even the implied            |
//   |  warranty of MERCHANTABILITY or FITNESS FOR A              |
//   |  PARTICULAR PURPOSE.  See the GNU General Public           |
//   |  License for more details.                                 |
//   |  You should have received a copy of the GNU                |
//   |  General Public License along with this program;           |
//   |  if not, write to the Free Software Foundation,            |
//   |  Inc., 675 Mass Ave, Cambridge, MA 02139, USA.             |
//   |------------------------------------------------------------|

clear
function resetfontsize()
h=get("hdl");
h.font_size=2;
ax=get("current_axes");
ax.x_label.font_size=2;
ax.y_label.font_size=2;
ax.title.font_size=2;
endfunction

ingfile=xgetfile('G*',title='Choose G=system matrix file ')
indfile=xgetfile('D*',title='Choose d=data vector file ')
inefile=xgetfile('E*',title='Choose e=elevations file ')

//read data
fp1=file('open',indfile,'old');
D=read(fp1,-1,2);
d=D(:,1);
flag=D(:,2);
file('close',fp1);

//read elevations
fp1=file('open',inefile,'old');
E=read(fp1,-1,3);
elv=E(:,3);
chan=E(:,1);
recv=E(:,2);
file('close',fp1);

nvarbl=evstr(x_dialog(['# shots '],['1']));
nshot=nvarbl(1);
//nchanl=length(elv);
nchanl=48;
ncols=nshot+nchanl+1;
//read system matrix 
fp1=file('open',ingfile,'old');
G=read(fp1,-1,ncols);
file('close',fp1);

[N,M]=size(G);
//nchanl=input('Enter number of channels ')
//nshot=input('Enter Number of Shots = ')
imax=nshot+nchanl+1;
GG=G(:,M);

//Compute Inverse
H=inv(GG'*GG)*GG';

m=H*d;

v1=1/m;
v1txt=sprintf("%d",ceil(v1));


//plot fit to times
dcal=GG*m;
for je=1:N
err(je,1)=d(je)-dcal(je);
end
disp('Sum Squared Error')
rms=sqrt((err'*err)/N);
rmstxt=sprintf("%f",rms);
// break into shot efforts (itogl)
jg=1;
k=0;
itogl=1;
for j=1:N
if G(j,jg)==1 then
k=k+1;
dplot(k,itogl)=d(j);
dcalplt(k,itogl)=dcal(j);
flagplt(k,itogl)=flag(j);
else
jg=jg+1;
itogl=itogl+1;
k=0;
end
end
// loop over shots
jmx=size(flagplt,2);
for j=1:jmx
test=max(flagplt(:,j));
 if test>0
 flg=flagplt(:,j);
 kmx=length(flg);
 kk=0;
   for k=1:kmx
     if dplot(k,j)>0
     kk=kk+1;
     doplt(kk)=dplot(k,j);
     fplt(kk)=flg(k);
     dcplt(kk)=dcalplt(k,j);
     end //endif
   end //next k
 kmx=kk;
 plot2d(fplt(1:kmx),doplt(1:kmx),style=-1)
 plot2d(fplt(1:kmx),dcplt(1:kmx),style=2,frameflag=0,axesflag=0)
 end //endif
end //next j
//compute velocity error bar
sigm2=inv(GG'*GG)*rms*rms;
sigv2=(1/(m*m))^2*sigm2;
sigv=sqrt(sigv2);
sigvtxt=sprintf("%f",sigv);
xtitle('Direct Wave: V1='+v1txt+' +/- '+sigvtxt,'STATION','Arrival Time (sec)');
xgrid(3);
resetfontsize();
xs2fig(0,'DirectPlot.fig',1)
