//   |------------------------------------------------------------|
//   | $Id: refplot2.sci,v 1.3 2009-05-08 22:03:48 pm Exp $       |
//   | Basic Seismic Utilities (BSU)                              |
//   | LANGUAGE: Scilab                                           |
//   | AUTHOR: P. MICHAELS                                        |
//   | FUNCTION NAME: refplot2.sci                                |
//   | DIRECTORY: BSUROOT/Scilab                                  |
//   | revised for scilab 4.0                                     |
//   |------------------------------------------------------------|
//   | purpose: read a BSEGY file and plot REFRACTION first       |
//   |          break picks, fit linear trend, get slope->velocity|
//   |------------------------------------------------------------|
//   | Scilab is an interpreter useful for scientifc calculations.|
//   | It is similar to MATLAB and may be obtained free from      |
//   | http://www-rocq.inria.fr/scilab                            |
//   | Scilab is available for many platforms, including LINUX    |
//   |------------------------------------------------------------|
//   |  NOTICE:                                                   |
//   |  Copyright (c) 2009 Paul Michaels                          |
//   |  <pm@cgiss.boisestate.edu>                                 |
//   |  This program is free software; you can                    |
//   |  redistribute it and/or modify it under the terms          |
//   |  of the GNU General Public License as published            |
//   |  by the Free Software Foundation; either version           |
//   |  3 of the License, or (at your option) any later           |
//   |  version.  This program is distributed in the              |
//   |  hope that it will be useful, but                          |
//   |  WITHOUT ANY WARRANTY; without even the implied            |
//   |  warranty of MERCHANTABILITY or FITNESS FOR A              |
//   |  PARTICULAR PURPOSE.  See the GNU General Public           |
//   |  License for more details.                                 |
//   |  You should have received a copy of the GNU                |
//   |  General Public License along with this program;           |
//   |  if not, write to the Free Software Foundation,            |
//   |  Inc., 675 Mass Ave, Cambridge, MA 02139, USA.             |
//   |------------------------------------------------------------|

clear

getf("segyinfo.sci");
getf("bsegin.sci");
getf("sclplot.sci");

//open data file with pointer fp1
msg='enter file name';
filen=input(msg,'string');
fp1=mopen(filen,'rb');

j=1;
kk=0;
[nbytes,ntraces,npts,fsamin]=segyinfo(fp1);
for k=1:ntraces
[data,frange,pic,rx,ry,rz,sx,sy,sz,sd,sp,vp,geoazi]=bsegin(fp1,npts,k);
  if (pic~=0.) then
  kk=kk+1;
  svpic(j,kk)=pic;
  svrx(j,kk)=rx;
  svsx(j,kk)=sx;
  svrange(j,kk)=frange;
  svvp(j,kk)=vp;
  end
end;    // next k
mclose(fp1);

//distance from shot
rxx=svrange;

//choose to plot stations or source-receiver offset
optns=['STATIONS';'OFFSET'];
n=x_choose(optns,['Choose X-Axis for Plot']);
if n==1 then iswx=0; end;
if n==2 then iswx=1; end;
if n==0 then abort end;

//assign rxx if needed
if iswx==0 then rxx=svrange; end;

//plot first arrivals
save0=zeros(8,1);
hold=0;
symbol=-1;
TITL="File:  "+filen;
if iswx==1 then
save1=sclplot(rxx(1,:),1000*svpic(1,:),TITL,"Offset","Picks (ms)",hold,save0,symbol);
else
save1=sclplot(svvp(1,:),1000*svpic(1,:),TITL,"Station","Picks (ms)",hold,save0,symbol);
end;
//hold=1;
//save0=sclplot(svrx(2,:),1000*svpic(2,:)," ","Station","Picks (ms)",hold,save1,-1);

//---------------------------------------------------------------------

optns=[' DONE PICKING';' DO AN INTERVAL'];
n=x_choose(optns,['Choose Option']);
if n==1 then isw1=0; end;
if n==2 then isw1=1; end;
if n==0 then break; end;

icnt=0;

//start loop
while isw1==1
icnt=icnt+1;

[y]=locate(2);
zmin=min(y(1,:));
zmax=max(y(1,:));
if zmin>zmax then
tmp1=zmin;
zmin=zmax;
zmax=tmp1;
end;  //endif

clear xx;
clear xxx;
clear yy;
clear yycal;

//...find min and max indexes
npts=length(rxx);

clear jindex;
jjc=1;

if iswx==1 then
  for j=1:npts
  if (rxx(j)>=zmin & rxx(j)<=zmax) then
    jindex(jjc)=j;
    jjc=jjc+1;
    end; //endif
  end; //next j
else
  for j=1:npts
  if (svvp(j)>=zmin & svvp(j)<=zmax) then
    jindex(jjc)=j;
    jjc=jjc+1;
    end; //endif
  end; //next j
end //endif

jmin=min(jindex);
jmax=max(jindex);
if jmin<1 then jmin=1; end;
if jmax>npts then jmax=npts; end;

//...load interval into yy
k=1;
for j=jmin:jmax
yy(k)=svpic(j);
xx(k)=rxx(j);
xxx(k)=svvp(j);
k=k+1;
end

//...compute internal sums needed for velocity st.dev.
nptf=length(yy);
sumx=0;
sumy=0;
sumxy=0;
sumx2=0;
for j=1:nptf
sumx=sumx+xx(j);
sumy=sumy+yy(j);
sumxy=sumxy+xx(j)*yy(j);
sumx2=sumx2+xx(j)^2;
end
summ=0;
for j=1:nptf
summ=summ+(sumx-nptf*xx(j))^2;
end

//linear regression
//[c1,c0,sig]=reglin(xx',yy');
//vf(icnt)=abs(1/c1);
//if iswx==0 then
//To(icnt)=(sx*c1+c0)*1000;
//else
//To(icnt)=(c0)*1000;
//end;

//linear regression OLS Inverse
G=[ones(xx),xx];
H=inv(G'*G)*G';
m=H*yy;
c0=m(1);  //intercept time
c1=m(2);  //slowness of refractor  1/Vref
vf(icnt)=abs(1/c1);
To(icnt)=(c0)*1000;

//compute calculated data
for k=1:nptf
yycal(k)=xx(k)*c1+c0;
end

//compute time standard deviation (for error bar)
e=yy-yycal;
sum1=e'*e;

//confidence limits, Student-T distribution
conf=95;
Q=(1-conf/100)/2;
P=1-Q;
DF=nptf-2;   //degrees freedom=number points-parameters
talpha=cdft("T",DF,P,Q);

//solution appraisal
//sigd=.0002^2;   //estimate of sdtv pick times
sigd=(2*fsamin)^2; //set to 2 samples for good data
//sigd=sum1/(nptf-2); //estimate from sum square error

Cd=eye(nptf,nptf)*sigd;  //covariance matrix, data
Cm=H*Cd*H';   //covariance matrix, parameters
sigto=sqrt(Cm(1,1))*1000;
sigslow=sqrt(Cm(2,2));
vtop=1/(c1-sigslow);
vbot=1/(c1+sigslow);
sigmav=(vtop-vbot)/2;

//apply Student-T to est. of variance
sigmav=sigmav*talpha;
sigto=sigto*talpha;

//compute velocity standard deviation
//sigmay=sqrt(sum1/(nptf-1));
//sigmav=-((sigmay)*sqrt(summ)*((sumx)^2-nptf*sumx2)/((sumx*sumy-nptf*sumxy)^2));
//sigmav=sigmav*1.96;  //95% confidence
msg2=sprintf('%4.0f (+/-%3.0f) m/s',vf(icnt),sigmav);
msg1=sprintf('To=%3.1f (+/-%3.1f) ms',To(icnt),sigto);

//plot fit and observed data in interval
if iswx==0 then
plot2d(xxx,yycal*1000,style=2,frameflag=0,axesflag=0);
else
plot2d(xx,yycal*1000,style=2,frameflag=0,axesflag=0);
end //endif

//Place standard deviation values on plot
[y]=locate(1);
a=y(1,1);
b=y(2,1);
xstring(a,b,[msg2;msg1]);

//Display Chi-Square Value
chisq=sum1/((nptf-2)*sigd);
chisqtxt=sprintf("Chi-Square=%4.2f",chisq);
x_message(chisqtxt);

optns=[' DONE PICKING';' DO AN INTERVAL'];
n=x_choose(optns,['Chooes Option']);
if n==1 then isw1=0; end;
if n==2 then isw1=1; end;
if n==0 then break; end;
//...end loop
end
