function [save0]=sclplot(x,y,title,labelx,labely,hold,save1,symbol)
//   |------------------------------------------------------------|
//   | $Id: sclplot.sci,v 1.4 2009-05-08 22:03:48 pm Exp $        |
//   | Basic Seismic Utilities (BSU)                              |
//   | LANGUAGE: Scilab                                           |
//   | AUTHOR: P. MICHAELS                                        |
//   | FUNCTION NAME: sclplot.sci                                 |
//   | DIRECTORY: BSUROOT/Scilab                                  |
//   |  revised for scilab 4.0                                    |
//   |------------------------------------------------------------|
//   | purpose: plots (x,y) to a desired paper scale.  Scaling    |
//   |          depends on if to be edited by XFIG, or just       |
//   |          going straight to a PostScript file.              |
//   |          GUI driven selection of scales, etc.              |
//   |                                                            |
//   | NOTE: more advanced than sclplot0.sci, here you have       |
//   |       option of saving scales for multiple plots.          |
//   |                                                            |
//   |------------------------------------------------------------|
//   | Scilab is an interpreter useful for scientifc calculations.|
//   | It is similar to MATLAB and may be obtained free from      |
//   | http://www-rocq.inria.fr/scilab                            |
//   | Scilab is available for many platforms, including LINUX    |
//   |------------------------------------------------------------|
//   |  NOTICE:                                                   |
//   |  Copyright (c) 2009 Paul Michaels                          |
//   |  <pm@cgiss.boisestate.edu>                                 |
//   |  This program is free software; you can                    |
//   |  redistribute it and/or modify it under the terms          |
//   |  of the GNU General Public License as published            |
//   |  by the Free Software Foundation; either version           |
//   |  3 of the License, or (at your option) any later           |
//   |  version.  This program is distributed in the              |
//   |  hope that it will be useful, but                          |
//   |  WITHOUT ANY WARRANTY; without even the implied            |
//   |  warranty of MERCHANTABILITY or FITNESS FOR A              |
//   |  PARTICULAR PURPOSE.  See the GNU General Public           |
//   |  License for more details.                                 |
//   |  You should have received a copy of the GNU                |
//   |  General Public License along with this program;           |
//   |  if not, write to the Free Software Foundation,            |
//   |  Inc., 675 Mass Ave, Cambridge, MA 02139, USA.             |
//   |------------------------------------------------------------|
// Scilab Plot to scales in inches
// scale plot: scaleplt.sci
// export to *.fig, then to *.ps from xfig

if hold==0 then 
optns=['Xfig';'PostScript'];
n=x_choose(optns,['Choose Scaling']);
if n==1 then exportsw=0; else exportsw=1; end;
if n==0 then break; end;
  else
exportsw=save1(1); xlong=save1(2); ylong=save1(3);
xmin=save1(4); xmax=save1(5); ymin=save1(6); ymax=save1(7);
gdon=save1(8);
end;  //endif hold

// if export to postscript *.eps file, use 5.75"
//exportsw=1;
// if export to xfig *.fig file, use 4.25"
// and export to *.ps from xfig
//exportsw=0;

//set origin (upper left corner) of plot in inches
// (landscape, (1.6",1.1") origin if xorg=yorg=0 and exportsw=1
// (landscape, (2.8",2.0") origin if xorg=yorg=0 and exportsw=0

//set plot origin
xorg=0.5;
yorg=0.5;

if hold==0 then 
//set default axes limits
xmin=min(x);
xmax=max(x);
ymin=min(y);
ymax=max(y);

//xmintxt=sprintf("%.1f",xmin);
//xmaxtxt=sprintf("%.1f",xmax);
//ymintxt=sprintf("%.1f",ymin);
//ymaxtxt=sprintf("%.1f",ymax);
xmintxt=string(xmin);
xmaxtxt=string(xmax);
ymintxt=string(ymin);
ymaxtxt=string(ymax);

labels=["Xmin";"Xmax";"Ymin";"Ymax"];
[ok,xmin,xmax,ymin,ymax]=getvalue("Get Axes Limits",labels,...
 list("vec",1,"vec",1,"vec",1,"vec",1),...
 [xmintxt; xmaxtxt; ymintxt; ymaxtxt])
if ok==%f then abort; end;

//set axes lengths in inches
xlong=4;  //set defaults
ylong=4;
xlongtxt=sprintf("%.1f",xlong);
ylongtxt=sprintf("%.1f",ylong);

labels=["X-axis Length (in)";"Y-axis Length (in)"];
[ok,xlong,ylong]=getvalue("Get Axes Lengths (inches)",labels,...
 list("vec",1,"vec",1),...
 [xlongtxt; ylongtxt])
if ok==%f then abort; end;

//  scale factors
if exportsw==1 then 
xscale=.70820/5.75;
yscale=1.0000/5.75;
else
xscale=(.70820/4.25);
yscale=(1.0000/4.25);
end

optns=['YES';'NO'];
n=x_choose(optns,['X-Grid On ?']);
if n==1 then gdon=1; else gdon=0; end;
if n==0 then break; end;

// apply scale factors
xorg=xorg*xscale/1.3; yorg=yorg*yscale/1.3;
xlong=xlong*xscale; ylong=ylong*yscale;
end;  //endif hold


//define subwindow
rect=[xorg,yorg,xlong,ylong];

if hold==0 then
//define tic marks (minor=nx,ny; major=Nx,Ny)
nx=2; ny=2;
Nx=5; Ny=5;
nxtxt=sprintf("%d",nx);
nytxt=sprintf("%d",ny);
Nxtxt=sprintf("%d",Nx);
Nytxt=sprintf("%d",Ny);

labels=["Nx (major)";"nx (minor)";"Ny (major)";"ny (minor)"];
[ok,Nx,nx,Ny,ny]=getvalue("Set Grid Tic Marks",labels,...
 list("vec",1,"vec",1,"vec",1,"vec",1),...
 [Nxtxt;nxtxt;Nytxt;nytxt])
if ok==%f then abort; end;

nax=[nx,Nx,ny,Ny];
end;  //endif hold

//axes limits  x-min,y-min, x-max, y-max
frect=[xmin,ymin,xmax,ymax]

xset("font",2,2);  //times, 12size
if hold==0 then
xsetech(rect,frect,"nn")
plotframe(frect,nax);
if gdon==1 then xgrid(3); end;
end;  //endif hold

plot2d(x,y,symbol,frameflag=0,axesflag=0);

// Label the plot
if hold==0 then
xtitle(title,labelx,labely);
end;  //endif hold

save0=[exportsw,xlong,ylong,xmin,xmax,ymin,ymax,gdon];

